#!/usr/bin/env python
import click
import codecs
import os
from lxml import etree

from nlppln.utils import create_dirs, out_file_name, get_files


@click.command()
@click.argument('in_dir', type=click.Path(exists=True))
@click.option('--out_dir', '-o', default=os.getcwd(), type=click.Path())
@click.option('--tag', default=None)
def xml_to_text(in_dir, out_dir, tag):
    create_dirs(out_dir)

    in_files = get_files(in_dir)

    for fi in in_files:
        with codecs.open(fi, encoding='utf-8') as f:
            root = etree.ElementTree().parse(f)
        if tag is not None:
            elements = list(root.iter('{*}' + tag))
        else:
            elements = [root]
        texts = []
        for el in elements:
            texts.append(' '.join(
                [e.text for e in el.iterdescendants() if
                    e.text is not None]))

        out_file = out_file_name(out_dir, fi, 'txt')
        with codecs.open(out_file, 'wb', encoding='utf-8') as f:
            f.write('\n'.join(texts))
            f.write('\n')


if __name__ == '__main__':
    xml_to_text()



#!/usr/bin/env python
import click
import os
from nlppln.utils import create_dirs


@click.command()
@click.argument('in_file', type=click.File(encoding='utf-8'))
@click.option('--out_dir', '-o', default=os.getcwd(), type=click.Path())
def lowercase(in_file, out_dir):
    create_dirs(out_dir)

    text = in_file.read()
    text = text.lower()

    stdout_text = click.get_text_stream('stdout')
    stdout_text.write(text)


if __name__ == '__main__':
    lowercase()



#!/usr/bin/env python
import click
import os
import codecs
import json
import pandas as pd

from nlppln.utils import create_dirs, get_files


@click.command()
@click.argument('in_dir', type=click.Path(exists=True))
@click.option('--out_dir', '-o', default=os.getcwd(), type=click.Path())
@click.option('--name', '-n', default='ner_stats.csv')
def nerstats(in_dir, out_dir, name):
    create_dirs(out_dir)

    frames = []

    in_files = get_files(in_dir)

    for fi in in_files:
        with codecs.open(fi, encoding='utf-8') as f:
            saf = json.load(f)
        data = {}
        data['word'] = [t['word'] for t in saf['tokens'] if 'ne' in t.keys()]
        data['ner'] = [t['ne'] for t in saf['tokens'] if 'ne' in t.keys()]
        data['w_id'] = [t['id'] for t in saf['tokens'] if 'ne' in t.keys()]
        data['text'] = [os.path.basename(fi)
                        for t in saf['tokens'] if 'ne' in t.keys()]

        frames.append(pd.DataFrame(data=data))

    df = pd.concat(frames, ignore_index=True)
    df.to_csv(os.path.join(out_dir, name), encoding='utf-8')


if __name__ == '__main__':
    nerstats()



#!/usr/bin/env python
import click
import codecs
import os
from bs4 import BeautifulSoup
from nlppln.utils import create_dirs, out_file_name


@click.command()
@click.argument('xml_file', type=click.File())
@click.option('--element', '-e', multiple=True)
@click.option('--out_dir', '-o', default=os.getcwd(), type=click.Path())
def command(xml_file, element, out_dir):
    create_dirs(out_dir)

    bs = BeautifulSoup(xml_file.read(), 'xml')

    for elem in element:
        to_empty = bs.find_all(elem)
        for t in to_empty:
            t.clear()

    out_file = out_file_name(out_dir, os.path.basename(xml_file.name))
    with codecs.open(out_file, 'wb', encoding='utf-8') as f:
        f.write(bs.prettify())

if __name__ == '__main__':
    command()



#!/usr/bin/env python
import click
import os
import codecs
import json
import pandas as pd


@click.command()
@click.argument('ner_csv_file', type=click.Path(exists=True))
@click.argument('input_files', nargs=-1, type=click.Path(exists=True))
@click.argument('output_dir', nargs=1, type=click.Path())
@click.option('--mode', default='replace')
def command(ner_csv_file, input_files, output_dir, mode):
    if not os.path.exists(output_dir):
        os.makedirs(output_dir)

    if mode not in ('replace', 'delete'):
        raise ValueError("Unknown mode: {mode}, "
                         "please choose either replace or delete"
                         .format(**locals()))

    ners = pd.read_csv(ner_csv_file, index_col=0, encoding='utf-8')
    ners = ners.fillna('NE')
    grouped = ners.groupby(['text'])

    for fi in input_files:
        with codecs.open(fi, encoding='utf-8') as f:
            saf = json.load(f)

        bn = os.path.basename(fi)
        if bn in grouped.groups.keys():
            df = grouped.get_group(bn).set_index('w_id')
            ner_data = df.to_dict()

            for t in saf['tokens']:
                if t['id'] in ner_data['text'].keys():
                    if mode == 'replace':
                        r = ner_data['ner'][t['id']]
                        t['word'] = r
                        t['lemma'] = r
                    elif mode == 'delete':
                        t['word'] = ''
                        t['lemma'] = ''

        out_file = os.path.join(output_dir, bn)
        with codecs.open(out_file, 'wb', encoding='utf-8') as f:
            json.dump(saf, f, indent=4)


if __name__ == '__main__':
    command()



#!/usr/bin/env python
import click
import os
import shutil
import uuid

from nlppln.utils import create_dirs, out_file_name


@click.command()
@click.argument('in_file', type=click.Path(exists=True))
@click.option('--rename', type=click.Choice(['random', 'spaces', 'copy']),
              default='spaces')
@click.option('--out_dir', '-o', default=os.getcwd(), type=click.Path())
def command(in_file, rename, out_dir):
    create_dirs(out_dir)

    ext = os.path.splitext(in_file)[1].replace('.', '')
    fname = os.path.basename(in_file)

    if rename == 'spaces':
        fname = fname.replace(' ', '-')
    elif rename == 'random':
        fname = '{}.{}'.format(uuid.uuid4(), ext)

    fo = out_file_name(out_dir, fname)
    shutil.copy2(in_file, fo)

if __name__ == '__main__':
    command()



#!/usr/bin/env python
import os
import click
from sklearn.feature_extraction.text import CountVectorizer
import numpy as np
import pandas as pd

from nlppln.utils import create_dirs, get_files, split


@click.command()
@click.argument('in_dir', type=click.Path(exists=True))
@click.option('--out_dir', '-o', default=os.getcwd(), type=click.Path())
@click.option('--name', '-n', default='freqs.csv')
def freqs(in_dir, out_dir, name):
    out_file = os.path.join(out_dir, name)
    create_dirs(out_file)

    in_files = get_files(in_dir)

    vectorizer = CountVectorizer(input='filename', tokenizer=split)
    X = vectorizer.fit_transform(in_files)
    freqs = np.array(X.sum(axis=0)).squeeze()
    vocab_df = pd.DataFrame(
        {'word': vectorizer.get_feature_names(), 'freq': freqs})
    vocab_df['rank'] = vocab_df['freq'].rank(method='first', ascending=False)
    vocab_df = vocab_df.sort('rank')
    vocab_df.to_csv(out_file, encoding='utf-8', index=False)


if __name__ == '__main__':
    freqs()



#!/usr/bin/env python
import click
import codecs
import os
import pandas as pd
import numpy as np

from sklearn.feature_extraction.text import CountVectorizer

from ..utils import create_dirs, get_files, split


def load_liwc_dict(dict_file, encoding):

    with codecs.open(dict_file, 'rb', encoding) as f:
        lines = f.readlines()

    liwc_categories = {}
    liwc_dict = {}

    for line in lines:
        # LIWC category
        if line[0].isdigit():
            entry = line.split()
            # remove 0 from strings like 01
            c = str(int(entry[0]))
            liwc_categories[c] = entry[1]
        # word
        elif line[0].isalpha():
            entry = line.split()
            term = entry[0]
            categories = entry[1:]
            liwc_dict[term] = categories
    return liwc_dict, liwc_categories


@click.command()
@click.argument('in_dir', type=click.Path(exists=True))
@click.argument('liwc_dict', type=click.Path(exists=True))
@click.option('--encoding', '-e', default='latin1',
              help='Encoding of LIWC dictionary.')
@click.option('--out_dir', '-o', default=os.getcwd(), type=click.Path())
@click.option('--name', '-n', default='liwc.csv')
def command(in_dir, liwc_dict, encoding, out_dir, name):
    create_dirs(out_dir)

    in_files = get_files(in_dir)

    liwc, liwc_categories = load_liwc_dict(liwc_dict, encoding)

    text_ids = [os.path.basename(fi) for fi in in_files]
    cols = liwc_categories.values()
    result = pd.DataFrame(0, index=text_ids, columns=cols)

    # make vocabulary
    count_vect = CountVectorizer(input='filename', tokenizer=split)
    word_counts = count_vect.fit_transform(in_files)

    # get total number of words per text
    result['#words'] = word_counts.sum(axis=1)

    # get words that match the liwc regexes (these should be added to the
    # vocabluary)
    liwc_regexes = [w for w in liwc.keys() if '*' in w]
    for w in liwc_regexes:
        # remove last character (*) from liwc entry
        start = w[0:len(w)-1]
        for word in count_vect.vocabulary_:
            if word.startswith(start):
                liwc[word] = liwc[w]
        del liwc[w]

    # get frequencies for all liwc words
    count_vect = CountVectorizer(input='filename', vocabulary=liwc.keys())
    word_counts = count_vect.fit_transform(in_files)

    # sum over categories
    # http://stackoverflow.com/questions/37013115/how-to-read-traverse-slice-scipy-sparse-matrices-lil-csr-coo-dok-faster
    word_counts_csc = word_counts.tocsc()
    for word, categories in liwc.iteritems():
        w_idx = count_vect.vocabulary_.get(word)
        col = np.zeros(len(in_files))
        A = word_counts_csc.getcol(w_idx)
        for i, d in zip(A.indices, A.data):
            col[i] = d

        for cat in categories:
            result[liwc_categories[cat]] += col

    lc = liwc_categories.values()
    result[lc] = result[lc].div(result['#words'], axis='index')
    result[lc] = result[lc]*100.0

    out_file = os.path.join(out_dir, name)
    result.to_csv(out_file, encoding='utf-8')


if __name__ == '__main__':
    command()



#!/usr/bin/env python
import click
import os

import pandas as pd

from nlppln.utils import create_dirs


@click.command()
@click.argument('ner_statistics', type=click.Path(exists=True))
@click.option('--keep', '-k', multiple=True, default=[u'PER', u'LOC'])
@click.option('--name', default='ner_statistics.csv')
@click.option('--out_dir', u'-o', default=os.getcwd(), type=click.Path())
def command(ner_statistics, keep, name, out_dir):
    df = pd.read_csv(ner_statistics, index_col=0, encoding='utf-8')

    df = df.query(u' or '.join([u'ner=="{}"'.format(k) for k in keep]))

    output_file = os.path.join(out_dir, name)
    create_dirs(output_file)
    df.to_csv(output_file, encoding='utf-8')

if __name__ == '__main__':
    command()



#!/usr/bin/env python
import click
import codecs
import os
import tika
from tika import parser

from nlppln.utils import create_dirs, out_file_name, get_files


@click.command()
@click.argument('in_dir', type=click.Path(exists=True))
@click.option('--out_dir', '-o', default=os.getcwd(), type=click.Path())
@click.option('--tika_server')
def command(in_dir, out_dir, tika_server):
    create_dirs(out_dir)

    in_files = get_files(in_dir)

    for fi in in_files:
        if tika_server:
            parsed = parser.from_file(fi, tika_server)
        else:
            parsed = parser.from_file(fi)

        out_file = out_file_name(out_dir, fi, 'txt')
        with codecs.open(out_file, 'wb', encoding='utf-8') as f:
            f.write(parsed['content'])


if __name__ == '__main__':
    command()



#!/usr/bin/env python
import click
import os
import codecs
import json
import datetime

from nlppln.utils import create_dirs, out_file_name, get_files


_POSMAP = {"VZ": "P",
           "N": "N",
           "ADJ": "A",
           "LET": ".",
           "VNW": "O",
           "LID": "D",
           "SPEC": "M",
           "TW": "Q",
           "WW": "V",
           "BW": "B",
           "VG": "C",
           "TSW": "I",
           "MWU": "U",
           "": "?",
           }


def parse_frog(lines):
    """
    Interpret the output of the frog parser.
    Input should be an iterable of lines (i.e. the output of call_frog)
    Result is a sequence of dicts representing the tokens
    """
    sid = 0
    for i, line in enumerate(lines):
        if not line:
            # end of sentence marker
            sid += 1
        else:
            parts = line.split("\t")
            tid, token, lemma, morph, pos, conf, ne, _, parent, rel = parts
            if rel:
                rel = (rel, int(parent) - 1)
            word = u' '.join(token.split(u'_'))
            result = dict(id=i, sentence=sid, word=word, lemma=lemma, pos=pos,
                          pos_confidence=float(conf), rel=rel)
            if ne != 'O':
                # NER label from BIO tags
                result["ne"] = ne.split('_', 1)[0][2:]
            yield result


def _add_pos1(token):
    """
    Adds a 'pos1' element to a frog token.
    """
    result = token.copy()
    result['pos1'] = _POSMAP[token['pos'].split("(")[0]]
    return result


def frog_to_saf(tokens):
    """
    Convert frog tokens into a new SAF document
    """
    tokens = [_add_pos1(token) for token in tokens]
    module = {'module': "frog",
              "started": datetime.datetime.now().isoformat()}
    return {"header": {'format': "SAF",
                       'format-version': "0.0",
                       'processed': [module]
                       }, "tokens": tokens}


@click.command()
@click.argument('in_dir', type=click.Path(exists=True))
@click.option('--out_dir', '-o', default=os.getcwd(), type=click.Path())
def frog2saf(in_dir, out_dir):
    create_dirs(out_dir)

    in_files = get_files(in_dir)

    for fi in in_files:
        with codecs.open(fi, encoding='utf-8') as f:
            lines = f.readlines()
            lines = [line.strip() for line in lines]
        saf_data = frog_to_saf(parse_frog(lines))

        head, tail = os.path.split(fi)
        fname = tail.replace(os.path.splitext(tail)[1], '')

        out_file = os.path.join(out_dir, out_file_name(out_dir, fname, 'json'))
        with codecs.open(out_file, 'wb', encoding='utf-8') as f:
            json.dump(saf_data, f, indent=4)


if __name__ == '__main__':
    frog2saf()



#!/usr/bin/env python
import os
import click
import codecs
import pandas as pd
import json
from collections import Counter

from nlppln.utils import create_dirs, out_file_name, get_files


@click.command()
@click.argument('in_dir', type=click.Path(exists=True))
@click.option('--out_dir', '-o', default=os.getcwd(), type=click.Path())
@click.option('--name', '-n', default='freqs.csv')
@click.option('--mode', default='word')
def freqs(in_dir, out_dir, name, mode):
    if mode not in ('word', 'lemma'):
        raise ValueError("Unknown mode: {mode}, "
                         "please choose either word or lemma"
                         .format(**locals()))
    output_file = out_file_name(out_dir, name)
    create_dirs(output_file)

    in_files = get_files(in_dir)

    cnt = Counter()
    for fi in in_files:
        with codecs.open(fi, encoding='utf-8') as f:
            saf = json.load(f)
        for token in saf['tokens']:
            word = token[mode]
            pos = token['pos1']
            cnt.update({(word, pos): 1})
    data = [(word, pos, count) for ((word, pos), count) in cnt.most_common()]
    vocab_df = pd.DataFrame(data, columns=[mode, 'pos', 'cnt'])
    vocab_df['rank'] = vocab_df.index + 1
    vocab_df.to_csv(output_file, encoding='utf-8', index=False)


if __name__ == '__main__':
    freqs()



from scriptcwl import WorkflowGenerator as WFGenerator

from .utils import CWL_PATH


class WorkflowGenerator(WFGenerator):
    def __init__(self, working_dir=None):
        WFGenerator.__init__(self, steps_dir=CWL_PATH, working_dir=working_dir)

        self.load(step_file='https://raw.githubusercontent.com/nlppln/'
                            'edlib-align/master/align.cwl')
        self.load(step_file='https://raw.githubusercontent.com/nlppln/'
                            'pattern-docker/master/pattern.cwl')

    def save(self, fname, validate=True, wd=False, inline=False, relative=True,
             pack=False, encoding='utf-8'):
        """Save workflow to file

        For nlppln, the default is to save workflows with relative paths.
        """
        super(WorkflowGenerator, self).save(fname,
                                            validate=validate,
                                            wd=wd,
                                            inline=inline,
                                            relative=relative,
                                            pack=pack,
                                            encoding=encoding)



#!/usr/bin/env python
import click
import codecs
import os

from nlppln.utils import create_dirs, out_file_name, get_files


@click.command()
@click.argument('in_dir', type=click.Path(exists=True))
@click.option('--out_dir', '-o', default=os.getcwd(), type=click.Path())
@click.option('--name', '-n', default='merged.csv')
def merge_csv(in_dir, out_dir, name):
    create_dirs(out_dir)

    in_files = get_files(in_dir)

    wrote_header = False

    out_file = out_file_name(out_dir, name)
    with codecs.open(out_file, 'wb', encoding='utf-8') as fo:
        for fi in in_files:
            with codecs.open(fi, encoding='utf-8') as f:
                lines = f.readlines()
            if len(lines) > 1:
                header = lines[0]
                data = lines[1:]

                # TODO: check if headers are the same
                if not wrote_header:
                    fo.write(header)
                    wrote_header = True
                for line in data:
                    fo.write(line)

if __name__ == '__main__':
    merge_csv()



# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from os import path


def read(fname):
    """Define read function to read README in long description."""
    return open(path.join(path.dirname(__file__), fname)).read()

here = path.abspath(path.dirname(__file__))

setup(
    name='nlppln',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version='0.3.1',

    description='NLP pipeline software using common workflow language',
    long_description=read('README.rst'),

    # The project's main homepage.
    url='https://github.com/nlppln/nlppln',

    # Author details
    author='Janneke van der Zwaan',
    author_email='j.vanderzwaan@esciencecenter.nl',

    # Choose your license
    license='Apache',

    include_package_data=True,

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: Apache Software License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6'
    ],

    # What does your project relate to?
    keywords='text-mining, nlp, pipeline',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(),

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=[
        'scipy',
        'pandas',
        'scriptcwl>=0.7.1',
        'lxml',
        'beautifulsoup4',
        'sklearn',
        'tika'],
    setup_requires=[
        # dependency for `python setup.py test`
        'pytest-runner',
        # dependencies for `python setup.py build_sphinx`
        'sphinx',
        'recommonmark'
    ],
    tests_require=[
        'pytest',
        'pytest-cov',
        'pycodestyle',
    ]

)



#!/usr/bin/env python
import click
import os
import json

from ..utils import cwl_file


@click.command()
@click.argument('dir_in', type=click.Path(exists=True))
@click.option('--recursive/--no-recursive', default=False)
@click.option('--endswith', default=None)
def command(dir_in, recursive, endswith):
    files_out = []

    if recursive:
        for root, dirs, files in os.walk(os.path.abspath(dir_in)):
            for f in files:
                files_out.append(cwl_file(os.path.join(root, f)))
    else:
        for f in os.listdir(dir_in):
            fi = os.path.join(dir_in, f)
            if os.path.isfile(fi):
                files_out.append(cwl_file(fi))

    # filter
    if endswith:
        files_out = filter(lambda x: x.get('path').endswith(endswith),
                           files_out)

    # order alphabetically on file name
    files_out = sorted(files_out, key=lambda x: x.get('path'))

    stdout_text = click.get_text_stream('stdout')
    stdout_text.write(json.dumps({'out_files': files_out}))


if __name__ == '__main__':
    command()



"""NLP pipeline utility functionality"""
import os
import shutil
import glob

MODULE_PATH = os.path.dirname(os.path.realpath(__file__))
CWL_PATH = os.path.abspath(os.path.join(MODULE_PATH, 'cwl'))

DEFAULT_DATA_DIR = '{}/.local/share/'.format(os.environ.get('HOME'))
CWL_DATA_DIR_PREFIX = 'commonwl'


def remove_ext(fname):
    """Removes the extension from a filename
    """
    bn = os.path.basename(fname)
    return os.path.splitext(bn)[0]


def create_dirs(fname):
    """Create (output) directories if they don't exist
    """
    fname = os.path.dirname(os.path.abspath(fname))

    if not os.path.exists(fname):
        os.makedirs(fname)


def out_file_name(out_dir, fname, ext=None):
    """Return path of output file, given a directory, file name and extension.

    If fname is a path, it is converted to its basename.

    Args:
        out_dir (str): path to the directory where output should be written.
        fname (str): path to the input file.
        ext (str): file extension of the output file (defaults to None).

    Returns:
        str: out_dir + fname with extension replaced. If `ext` is `None`, the
            original extension is kept.
    """
    if ext is None:
        return os.path.join(out_dir, os.path.basename(fname))

    fname = remove_ext(fname)
    return os.path.join(out_dir, '{}.{}'.format(fname, ext))


def cwl_file(fname):
    return {'class': 'File', 'path': fname}


def copy_cwl_files(from_dir=CWL_PATH):
    """Copy cwl files to a directory where the cwl-runner can find them.

    cwl files are copied to $XDG_DATA_HOME/commonwl/ This is one of the default
    locations where the cwl-runner looks for cwl files.

    Args:
        from_dir (str): Path to directory where to copy files from (default:
            the cwl directory of nlppln).
    """
    cwl_data_dir = os.environ.get('XDG_DATA_HOME')
    if not cwl_data_dir:
        cwl_data_dir = DEFAULT_DATA_DIR

    cwl_data_dir = os.path.join(cwl_data_dir, CWL_DATA_DIR_PREFIX)

    create_dirs(cwl_data_dir)

    cwl_files = glob.glob('{}{}*.cwl'.format(from_dir, os.sep))
    for fi in cwl_files:
        fo = os.path.join(cwl_data_dir, os.path.basename(fi))
        shutil.copy2(fi, fo)


def get_files(directory):
    """Return a list of all files in the directory."""
    files_out = []
    for f in os.listdir(directory):
        fi = os.path.join(directory, f)
        if os.path.isfile(fi):
            files_out.append(fi)

    # order alphabetically on file name
    return sorted(files_out)


def split(s):
    return s.split()


if __name__ == '__main__':
    copy_cwl_files()



#!/usr/bin/env python
import click
import os
import codecs
import json

from nlppln.utils import create_dirs, out_file_name, get_files


@click.command()
@click.argument('in_dir', type=click.Path(exists=True))
@click.option('--out_dir', '-o', default=os.getcwd(), type=click.Path())
@click.option('--mode', default='word')
def saf_to_text(in_dir, out_dir, mode):
    create_dirs(out_dir)

    if mode not in ('word', 'lemma'):
        raise ValueError("Unknown mode: {mode}, "
                         "please choose either word or lemma"
                         .format(**locals()))

    in_files = get_files(in_dir)

    for fi in in_files:
        with codecs.open(fi, encoding='utf-8') as f:
            saf = json.load(f)

        s_id = None
        lines = []

        for t in saf['tokens']:
            if s_id is None:
                s_id = t['sentence']
                sentence = []
            elif t['sentence'] != s_id:
                lines.append(u' '.join(sentence))
                sentence = []
                s_id = t['sentence']

            sentence.append(t[mode])

        out_file = out_file_name(out_dir, os.path.basename(fi), ext='txt')
        with codecs.open(out_file, 'wb', encoding='utf-8') as f:
            f.write(u'\n'.join(lines))
            f.write(u'\n')


if __name__ == '__main__':
    saf_to_text()



#!/usr/bin/env python
import click
import codecs
import json
import os
import pandas as pd

from nlppln.utils import create_dirs, get_files


@click.command()
@click.argument('in_dir', type=click.Path(exists=True))
@click.argument('meta_out', type=click.Path())
def basic_text_statistics(in_dir, meta_out):
    create_dirs(meta_out)

    d = {'num_words': [], 'num_sentences': []}

    text_names = []

    in_files = get_files(in_dir)

    for fi in in_files:
        with codecs.open(fi, encoding='utf-8') as f:
            text = json.load(f, encoding='utf-8')

        text_id = os.path.splitext(os.path.basename(fi))[0]
        text_names.append(text_id)
        d['num_words'].append(len(text['tokens']))
        sentences = [t['sentence'] for t in text['tokens']]
        num_sentences = len(set(sentences))
        d['num_sentences'].append(num_sentences)

    df = pd.DataFrame(d, index=text_names)
    df.to_csv(meta_out, encoding='utf-8')


if __name__ == '__main__':
    basic_text_statistics()



#!/usr/bin/env python
import click
import codecs
import os
import re

from string import punctuation

from nlppln.utils import create_dirs, out_file_name


def normalize_whitespace(text):
    return u' '.join(text.split())


def normalize_punctuation(text):
    for c in punctuation:
        try:
            if c == u'.':
                text = re.sub(r'\{}+'.format(c), c, text)
            else:
                text = re.sub(r'{}+'.format(c), c, text)
        except:
            if c != u'\\':
                text = re.sub(r'\{}+'.format(c), c, text)
    return text


@click.command()
@click.argument('txt', type=click.File(encoding='utf-8'))
@click.option('--out_dir', '-o', default=os.getcwd(), type=click.Path())
def normalize_whitespace_punctuation(txt, out_dir):
    create_dirs(out_dir)

    text = txt.read()
    text = normalize_whitespace(text)
    text = normalize_punctuation(text)

    out_file = out_file_name(out_dir, os.path.basename(txt.name))
    with codecs.open(out_file, 'wb', encoding='utf-8') as f:
        f.write(text)


if __name__ == '__main__':
    normalize_whitespace_punctuation()
